@@ -29,6 +29,24 @@ from thirdweb.types.tx import TxResultWithId
 
 
 class Edition(ERC1155[TokenERC1155]):
+    """
+    Create a collection of NFTs that lets you mint multiple copies of each NFT.
+
+    ```python
+    from thirdweb import ThirdwebSDK
+    from eth_account import Account
+    from web3 import Web3
+
+    # You can switch out this provider and RPC URL for your own
+    provider = Web3(Web3.HTTPProvider("<RPC_URL>"))
+    # This will create a random account to use for signing transactions
+    signer = Account.create()
+
+    sdk = ThirdwebSDK(provider, signer)
+    contract = sdk.get_edition("{{contract_address}}")
+    ```
+    """
+
     _abi_type = TokenERC1155
 
     contract_type: Final[ContractType] = ContractType.EDITION
@@ -86,6 +104,26 @@ class Edition(ERC1155[TokenERC1155]):
         """
         Mint a new NFT to the specified wallet
 
+        ```python
+        from thirdweb.types.nft import NFTMetadataInput, EditionMetadataInput
+
+        # Note that you can customize this metadata however you like
+        metadata_with_supply = EditionMetadataInput(
+            NFTMetadataInput.from_json({
+                "name": "Cool NFT",
+                "description": "This is a cool NFT",
+                "image": open("path/to/file.jpg", "rb"),
+            }),
+            100
+        )
+
+        # You can pass in any address here to mint the NFT to
+        tx = contract.mint_to("{{wallet_address}}", metadata_with_supply)
+        receipt = tx.receipt
+        token_id = tx.id
+        nft = tx.data()
+        ```
+
         :param to: wallet address to mint the NFT to
         :param metadata_with_supply: EditionMetadataInput for the NFT to mint
         :returns: receipt, id, and metadata of the mint
@@ -157,6 +195,36 @@ class Edition(ERC1155[TokenERC1155]):
         """
         Mint a batch of NFTs to the specified wallet
 
+        ```python
+        from thirdweb.types.nft import NFTMetadataInput, EditionMetadataInput
+
+        # Note that you can customize this metadata however you like
+        metadatas_with_supply = [
+            EditionMetadataInput(
+                NFTMetadataInput.from_json({
+                    "name": "Cool NFT",
+                    "description": "This is a cool NFT",
+                    "image": open("path/to/file.jpg", "rb"),
+                }),
+                100
+            ),
+            EditionMetadataInput(
+                NFTMetadataInput.from_json({
+                    "name": "Cooler NFT",
+                    "description": "This is a cooler NFT",
+                    "image": open("path/to/file.jpg", "rb"),
+                }),
+                100
+            )
+        ]
+
+        # You can pass in any address here to mint the NFT to
+        txs = contract.mint_to("{{wallet_address}}", metadata_with_supply)
+        receipt = txs[0].receipt
+        token_id = txs[0].id
+        nft = txs[0].data()
+        ```
+
         :param to: wallet address to mint the NFTs to
         :param metadatas_with_supply: list of EditionMetadataInput for the NFTs to mint
         :returns: receipts, ids, and metadatas of the mint
