@@ -3,6 +3,7 @@
 from time import time
 from thirdweb.common.error import ListingNotFoundException
 from thirdweb.constants.currency import ZERO_ADDRESS
+from thirdweb.core.classes.contract_events import ContractEvents
 from thirdweb.core.classes.contract_platform_fee import ContractPlatformFee
 from thirdweb.types.marketplace import (
     AuctionListing,
@@ -30,6 +31,24 @@ from web3 import Web3
 
 
 class Marketplace(BaseContract[MarketplaceABI]):
+    """
+    Create your own whitelabel marketplace that enables users to buy and sell any digital assets.
+
+    ```python
+    from thirdweb import ThirdwebSDK
+    from eth_account import Account
+    from web3 import Web3
+
+    # You can switch out this provider and RPC URL for your own
+    provider = Web3(Web3.HTTPProvider("<RPC_URL>"))
+    # This will create a random account to use for signing transactions
+    signer = Account.create()
+
+    sdk = ThirdwebSDK(provider, signer)
+    contract = sdk.get_marketplace("{{contract_address}}")
+    ```
+    """
+
     _abi_type = MarketplaceABI
     _storage: IpfsStorage
 
@@ -41,6 +60,7 @@ class Marketplace(BaseContract[MarketplaceABI]):
     platform_fee: ContractPlatformFee[MarketplaceABI]
     direct: MarketplaceDirect
     auction: MarketplaceAuction
+    events: ContractEvents[MarketplaceABI]
 
     def __init__(
         self,
@@ -61,6 +81,7 @@ class Marketplace(BaseContract[MarketplaceABI]):
         self.platform_fee = ContractPlatformFee(contract_wrapper)
         self.direct = MarketplaceDirect(contract_wrapper, storage)
         self.auction = MarketplaceAuction(contract_wrapper, storage)
+        self.events = ContractEvents(contract_wrapper)
 
     """
     READ FUNCTIONS
@@ -90,6 +111,11 @@ class Marketplace(BaseContract[MarketplaceABI]):
         """
         Get all the currently active listings from the marketplace.
 
+        ```python
+        listings = contract.get_active_listings()
+        price_of_first = listings[0].price
+        ```
+
         :return: List of listings
         """
         raw_listings = self._get_all_listings_no_filter()
@@ -113,6 +139,11 @@ class Marketplace(BaseContract[MarketplaceABI]):
         """
         Get all the listings that have ever been made on this marketplace.
 
+        ```python
+        listings = contract.get_all_listings()
+        price_of_first = listings[0].price
+        ```
+
         :param filter: Filter to apply to the listings
         :return: List of listings
         """
@@ -195,6 +226,13 @@ class Marketplace(BaseContract[MarketplaceABI]):
         """
         Buyout a listing by listing ID
 
+        ```python
+        listing_id = 0
+        quantity_desired = 1
+
+        contract.buyout_listing(listing_id, quantity_desired)
+        ```
+
         :param listing_id: ID of the listing to buyout
         :param quantity_desired: Quantity to buyout
         :param receiver: Address to send the asset to
@@ -220,6 +258,11 @@ class Marketplace(BaseContract[MarketplaceABI]):
         """
         Set the bid buffer basis points for this marketplace.
 
+        ```python
+        buffer_bps = 500
+        contract.set_bid_buffer_bps(buffer_bps)
+        ```
+
         :param buffer_bps: Bid buffer basis points
         :return: Transaction receipt
         """
@@ -234,6 +277,11 @@ class Marketplace(BaseContract[MarketplaceABI]):
         """
         Set the time buffer of the marketplace.
 
+        ```python
+        buffer_in_seconds = 60
+        contract.set_time_buffer_in_seconds(buffer_in_seconds)
+        ```
+
         :param buffer_in_seconds: Time buffer in seconds
         :return: Transaction receipt
         """
