@@ -1,6 +1,7 @@
 """Interface for interacting with an nft collection contract"""
 
 from thirdweb.constants.role import Role
+from thirdweb.core.classes.contract_events import ContractEvents
 from thirdweb.core.classes.contract_metadata import ContractMetadata
 from thirdweb.core.classes.contract_platform_fee import ContractPlatformFee
 from thirdweb.core.classes.contract_roles import ContractRoles
@@ -26,6 +27,24 @@ from thirdweb.types.tx import TxResultWithId
 
 
 class NFTCollection(ERC721[TokenERC721]):
+    """
+    Create a collection of one-of-one NFTs.
+
+    ```python
+    from thirdweb import ThirdwebSDK
+    from eth_account import Account
+    from web3 import Web3
+
+    # You can switch out this provider and RPC URL for your own
+    provider = Web3(Web3.HTTPProvider("<RPC_URL>"))
+    # This will create a random account to use for signing transactions
+    signer = Account.create()
+
+    sdk = ThirdwebSDK(provider, signer)
+    contract = sdk.get_nft_collection("{{contract_address}}")
+    ```
+    """
+
     _abi_type = TokenERC721
 
     contract_type: Final[ContractType] = ContractType.NFT_COLLECTION
@@ -37,6 +56,7 @@ class NFTCollection(ERC721[TokenERC721]):
     platform_fee: ContractPlatformFee[TokenERC721]
     royalty: ContractRoyalty[TokenERC721]
     signature: ERC721SignatureMinting
+    events: ContractEvents[TokenERC721]
 
     def __init__(
         self,
@@ -60,6 +80,7 @@ class NFTCollection(ERC721[TokenERC721]):
         self.signature = ERC721SignatureMinting(
             contract_wrapper, self.roles, self._storage
         )
+        self.events = ContractEvents(contract_wrapper)
 
     """
     WRITE FUNCTIONS
@@ -83,6 +104,23 @@ class NFTCollection(ERC721[TokenERC721]):
         """
         Mint a new NFT to the specified wallet
 
+        ```python
+        from thirdweb.types.nft import NFTMetadataInput
+
+        # Note that you can customize this metadata however you like
+        metadata = NFTMetadataInput.from_json({
+            "name": "Cool NFT",
+            "description": "This is a cool NFT",
+            "image": open("path/to/file.jpg", "rb"),
+        })
+
+        # You can pass in any address here to mint the NFT to
+        tx = contract.mint_to("{{wallet_address}}", metadata)
+        receipt = tx.receipt
+        token_id = tx.id
+        nft = tx.data()
+        ```
+
         :param to: wallet address to mint the NFT to
         :param metadata: metadata of the NFT to mint
         :returns: receipt, id, and metadata for the mint
@@ -119,6 +157,30 @@ class NFTCollection(ERC721[TokenERC721]):
         """
         Mint a batch of new NFTs to the specified wallet
 
+        ```python
+        from thirdweb.types.nft import NFTMetadataInput
+
+        # You can customize this metadata however you like
+        metadatas = [
+            NFTMetadataInput.from_json({
+                "name": "Cool NFT",
+                "description": "This is a cool NFT",
+                "image": open("path/to/file.jpg", "rb"),
+            }),
+            NFTMetadataInput.from_json({
+                "name": "Cooler NFT",
+                "description": "This is a cooler NFT",
+                "image": open("path/to/file.jpg", "rb"),
+            }),
+        ]
+
+        # You can pass in any address here to mint the NFT to
+        txs = contract.mint_batch_to("{{wallet_address}}", metadatas)
+        receipt = txs[0].receipt
+        first_token_id = txs[0].id
+        first_nft = txs[0].data()
+        ```
+
         :param to: wallet address to mint the NFTs to
         :param metadatas: list of metadata of the NFTs to mint
         :returns: receipts, ids, and metadatas for each mint
