@@ -1,4 +1,7 @@
+from thirdweb.abi.thirdweb_contract import ThirdwebContract
+from thirdweb.common.feature_detection import fetch_contract_metadata
 from thirdweb.contracts import Marketplace
+from thirdweb.contracts.custom import CustomContract
 from thirdweb.contracts.edition_drop import EditionDrop
 from thirdweb.contracts.nft_drop import NFTDrop
 from thirdweb.core.classes.contract_deployer import ContractDeployer
@@ -7,17 +10,21 @@ from thirdweb.core.classes.provider_handler import ProviderHandler
 from thirdweb.contracts import Token, Edition, NFTCollection
 
 from eth_account.account import LocalAccount
-from typing import Any, Dict, Optional, Type, Union, cast
+from typing import Dict, Optional, Type, Union, cast
 from web3 import Web3
 
 from thirdweb.types.sdk import SDKOptions
 
 
 class ThirdwebSDK(ProviderHandler):
+    """
+    The main entry point for the Thirdweb SDK.
+    """
+
     __contract_cache: Dict[
         str, Union[NFTCollection, Edition, Token, Marketplace, NFTDrop, EditionDrop]
     ] = {}
-    __storage: IpfsStorage
+    storage: IpfsStorage
 
     deployer: ContractDeployer
 
@@ -38,7 +45,7 @@ class ThirdwebSDK(ProviderHandler):
         """
 
         super().__init__(provider, signer, options)
-        self.__storage = storage
+        self.storage = storage
         self.deployer = ContractDeployer(provider, signer, options, storage)
 
     def get_nft_collection(self, address: str) -> NFTCollection:
@@ -101,6 +108,29 @@ class ThirdwebSDK(ProviderHandler):
 
         return cast(EditionDrop, self._get_contract(address, EditionDrop))
 
+    def get_custom_contract(self, address: str, abi: str = ""):
+        """
+        Get an SDK interface for any custom contract! If you deployed the contract with
+        the thirdweb CLI, you won't need to specify an ABI. Alternatively, you can
+        alternatively specify an ABI if you're contract doesn't have one uploaded.
+
+        :param address: address of the contract
+        :param abi: optional ABI to use for the contract
+        :returns: Custom contract SDK instance
+        """
+
+        if not abi:
+            try:
+                contract = ThirdwebContract(self.get_provider(), address)
+                metadata_uri = contract.get_publish_metadata_uri.call()
+                abi = fetch_contract_metadata(metadata_uri, self.storage)
+            except Exception as e:
+                raise Exception("Error fetching ABI for this contract: " + str(e))
+
+        return CustomContract(
+            self.get_provider(), address, abi, self.storage, self.get_signer()
+        )
+
     def update_provider(self, provider: Web3):
         """
         Update the provider instance used by the SDK.
@@ -143,7 +173,7 @@ class ThirdwebSDK(ProviderHandler):
         contract = contract_type(
             self.get_provider(),
             address,
-            self.__storage,
+            self.storage,
             self.get_signer(),
             self.get_options(),
         )
